@@ -34,8 +34,8 @@
 #include <kiconloader.h>
 #include <kfinddialog.h>
 #include <kurldrag.h>
-#include <kaction.h>
-#include <klocale.h>
+#include <tdeaction.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 #include "playlistview.h"
@@ -106,8 +106,8 @@ KDE_NO_CDTOR_EXPORT void RootPlayListItem::paintCell (TQPainter * p, const TQCol
 
 //-----------------------------------------------------------------------------
 
-KDE_NO_CDTOR_EXPORT PlayListView::PlayListView (TQWidget * parent, View * view, KActionCollection * ac)
- : KListView (parent, "kde_kmplayer_playlist"),
+KDE_NO_CDTOR_EXPORT PlayListView::PlayListView (TQWidget * parent, View * view, TDEActionCollection * ac)
+ : TDEListView (parent, "kde_kmplayer_playlist"),
    m_view (view),
    m_find_dialog (0L),
    m_active_color (30, 0, 255),
@@ -125,15 +125,15 @@ KDE_NO_CDTOR_EXPORT PlayListView::PlayListView (TQWidget * parent, View * view,
     setPaletteBackgroundColor (TQColor (0, 0, 0));
     setPaletteForegroundColor (TQColor (0xB2, 0xB2, 0xB2));
     m_itemmenu = new TQPopupMenu (this);
-    folder_pix = KGlobal::iconLoader ()->loadIcon (TQString ("folder"), KIcon::Small);
-    auxiliary_pix = KGlobal::iconLoader ()->loadIcon (TQString ("folder_grey"), KIcon::Small);
-    video_pix = KGlobal::iconLoader ()->loadIcon (TQString ("video"), KIcon::Small);
-    info_pix = KGlobal::iconLoader ()->loadIcon (TQString ("messagebox_info"), KIcon::Small);
-    img_pix = KGlobal::iconLoader ()->loadIcon (TQString ("colorize"), KIcon::Small);
-    unknown_pix = KGlobal::iconLoader ()->loadIcon (TQString ("unknown"), KIcon::Small);
-    menu_pix = KGlobal::iconLoader ()->loadIcon (TQString ("player_playlist"), KIcon::Small);
-    config_pix = KGlobal::iconLoader ()->loadIcon (TQString ("configure"), KIcon::Small);
-    url_pix = KGlobal::iconLoader ()->loadIcon (TQString ("www"), KIcon::Small);
+    folder_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("folder"), TDEIcon::Small);
+    auxiliary_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("folder_grey"), TDEIcon::Small);
+    video_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("video-x-generic"), TDEIcon::Small);
+    info_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("messagebox_info"), TDEIcon::Small);
+    img_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("colorize"), TDEIcon::Small);
+    unknown_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("unknown"), TDEIcon::Small);
+    menu_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("player_playlist"), TDEIcon::Small);
+    config_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("configure"), TDEIcon::Small);
+    url_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("www"), TDEIcon::Small);
     m_find = KStdAction::find (TQT_TQOBJECT(this), TQT_SLOT (slotFind ()), ac, "find");
     m_find_next = KStdAction::findNext (TQT_TQOBJECT(this), TQT_SLOT(slotFindNext()), ac, "next");
     m_find_next->setEnabled (false);
@@ -157,7 +157,7 @@ int PlayListView::addTree (NodePtr root, const TQString & source, const TQString
     ritem->source = source;
     ritem->icon = icon;
     ritem->setPixmap (0, !ritem->icon.isEmpty ()
-            ? KGlobal::iconLoader ()->loadIcon (ritem->icon, KIcon::Small)
+            ? TDEGlobal::iconLoader ()->loadIcon (ritem->icon, TDEIcon::Small)
             : url_pix);
     updateTree (ritem, 0L, false);
     return last_id;
@@ -337,7 +337,7 @@ KDE_NO_EXPORT TQDragObject * PlayListView::dragObject () {
 
 KDE_NO_EXPORT void PlayListView::setFont (const TQFont & fnt) {
     setTreeStepSize (TQFontMetrics (fnt).boundingRect ('m').width ());
-    KListView::setFont (fnt);
+    TDEListView::setFont (fnt);
 }
 
 KDE_NO_EXPORT void PlayListView::contextMenuItem (TQListViewItem * vi, const TQPoint & p, int) {
@@ -350,16 +350,16 @@ KDE_NO_EXPORT void PlayListView::contextMenuItem (TQListViewItem * vi, const TQP
                 m_find_next->unplug (m_itemmenu);
                 m_itemmenu->clear ();
             }
-            m_itemmenu->insertItem (KGlobal::iconLoader ()->loadIconSet
-                    (TQString ("editcopy"), KIcon::Small, 0, true),
+            m_itemmenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet
+                    (TQString ("edit-copy"), TDEIcon::Small, 0, true),
                     i18n ("&Copy to Clipboard"),
                     this, TQT_SLOT (copyToClipboard ()), 0, 0);
             if (item->m_attr ||
                     (item->node && (item->node->isPlayable () ||
                                     item->node->isDocument ()) &&
                      item->node->mrl ()->bookmarkable))
-                m_itemmenu->insertItem (KGlobal::iconLoader ()->loadIconSet
-                        (TQString ("bookmark_add"), KIcon::Small, 0, true),
+                m_itemmenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet
+                        (TQString ("bookmark_add"), TDEIcon::Small, 0, true),
                         i18n ("&Add Bookmark"),
                         this, TQT_SLOT (addBookMark ()), 0, 1);
             if (ritem->have_dark_nodes) {
@@ -530,14 +530,14 @@ KDE_NO_EXPORT void PlayListView::rename (TQListViewItem * qitem, int c) {
     if (rootItem (qitem)->show_all_nodes && item && item->m_attr) {
         PlayListItem * pi = static_cast <PlayListItem *> (qitem->parent ());
         if (pi && pi->node && pi->node->isEditable ())
-            KListView::rename (item, c);
+            TDEListView::rename (item, c);
     } else if (item && item->node && item->node->isEditable ()) {
         if (!rootItem (qitem)->show_all_nodes &&
                 item->node->isPlayable () &&
                 item->node->mrl ()->pretty_name.isEmpty ())
             // populate() has crippled src, restore for editing 
             item->setText (0, item->node->mrl ()->src);
-        KListView::rename (item, c);
+        TDEListView::rename (item, c);
     }
 }
 
